--------------------------------------------------------------------------------
--
-- Title       : Scanner FPGA
-- Design      : WatchDog
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : WatchDog.vhd
-- Generated   : Mar 15  2015
--------------------------------------------------------------------------------
--
-- Description : Generate nRequestOut active - 0 after TimeOutSize clocks from
--               last RequestRiseIn . If RequestRiseIn period < TimeOutSize
--							 nRequestOut always = 1
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 15/03/15	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity WatchDog is
GENERIC (TimeOutRange : integer);                                               -- Max. Number of Rise Enable pulses for time out
 port
  (
 	  ClockIn  ,                       																					 	-- Global Clock
	  nResetIn,                        																						-- General Reset active High
		ClockEnIn,											 																						-- Rise Enable of Global Clock for count time out
	  RequestRiseIn 									 																						-- Start measure of timeout RequestRiseIn
																		 																						-- For generate nRequestOut active - 0
									: in std_logic;
		TimeOutSize		                   																					 	-- Number of clocks after last
									: in  integer range 0 to TimeOutRange;
	  nRequestOut,
		nRequestRiseOut
									: out std_logic
	 );
end WatchDog;


architecture ArchWatchDog of WatchDog is
signal TimeOutCount : integer range 0 to TimeOutRange;
signal nRequest,
			 RequestFF
									: std_logic := '0';

begin

nRequestOut <= nRequest;																												-- TimeOut active - 0

 WatchDogProcess:
process (ClockIn)
begin
if ClockIn'event and ClockIn = '0' then
 case nResetIn is
  when '0' =>
   TimeOutCount	<= TimeOutSize;
	 nRequest      <= '1' ;
  when others =>
	 if (RequestRiseIn = '1') then
    TimeOutCount	<= TimeOutSize;
	  nRequest      <= '1' ;
	 elsif (TimeOutCount = 0 ) then
	  TimeOutCount <= 0 ;
	  nRequest     <= '0' ;
	 else
		case ClockEnIn is
		 when '1' =>
  	  TimeOutCount <= TimeOutCount - 1;
	    nRequest     <= '1' ;
		 when others =>
  	  TimeOutCount <= TimeOutCount;
	    nRequest     <= nRequest ;
		end case;
	 end if ;
 end case;
end if;
end process  WatchDogProcess;

 RequestRise_Process:
process (ClockIn)
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
		nRequestRiseOut <= '0';
		RequestFF       <= '0';
	 when others =>
	  RequestFF       <= nRequest;
		nRequestRiseOut <= RequestFF and(not nRequest);
	end case;
 end if;
end process  RequestRise_Process;

end ArchWatchDog;
