--------------------------------------------------------------------------------
--
-- Title       : Scanner FPGA
-- Design      : WatchDog Test
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : WatchDog_Tb.vhd
-- Generated   : May 23  2015
--------------------------------------------------------------------------------
--
-- Description : Generate nRequestOut active - 0 after TimeOutSize clocks from
--               last RequestRiseIn . If RequestRiseIn period < TimeOutSize
--							 nRequestOut always = 1
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 23/03/20	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity WatchDog_Tb is
end WatchDog_Tb;


architecture ArchWatchDog_Tb of WatchDog_Tb is
signal Clock,       																 		 		 		 		 		 					-- Clock
		   nClock,
			 ClockEn,
 			 RequestRise, 									 																					-- Start measure of timeout RequestRiseIn															 																						-- For generate nRequestOut active - 0
			 ClockEnRise

										: std_logic := '0';
signal nReset,          																												-- General Reset active Low
			 nRequest,
			 nRequestRise
										: std_logic := '1';

signal TimeOutSize		                   																				-- Number of clocks after last
										: integer range 0 to 7 := 5;

begin
Clock 		<= not Clock after 10 nS;     																				-- Clock 50.000 MHz
nClock 		<= not Clock ;     																										-- not Clock 50.000 MHz
nReset		<= '1','0' after 50 nS,'1' after 100 nS;         											-- General Reset active Low
ClockEn 	<= not ClockEn after 100 nS;


WatchDog_UUT : entity work.WatchDog
GENERIC MAP(7)									                                                -- Number of Rise Enable pulses for time out
 port map
  (
    ClockIn 				=> Clock,      																							-- General Clock
    nClockIn 				=> nClock,      																						-- General Clock
	  nResetIn				=> nReset,																									-- General Reset active low
		ClockEnIn 			=> ClockEnRise,											 												-- Rise Enable of Global Clock for count time out
	  RequestRiseIn 	=> RequestRise, 									 													-- Start measure of timeout RequestRiseIn
																		 																						-- For generate nRequestOut active - 0
		TimeOutSize	 		=> TimeOutSize,	                   													-- Number of clocks after last request
	  nRequestOut	 		=> nRequest,
		nRequestRiseOut	=> nRequestRise
	 );


DigDef_Inst : entity work.DigDef
port map
 (
  ClockIn 			=> Clock,      																										-- General Clock
  nClockIn			=> nClock,
  nResetIn			=> nReset,																												-- General Reset active low
	InputSignal 	=> ClockEn,
  RiseOutput 		=> ClockEnRise,											 														-- Rise Enable of Global Clock for count time out
	FallOutput 		=> open
 );

 TestProcess:
process
begin
RequestRise	<= '0';                                                             -- Start measure of timeout RequestRiseIn

wait for 200 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 1500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';


wait for 1500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 800 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait for 500 nS;
wait until Clock'event and Clock = '1';
RequestRise	<= '1';
wait until Clock'event and Clock = '1';
RequestRise	<= '0';

wait;
end process  TestProcess;


end ArchWatchDog_Tb;
